<?php
/*
Plugin Name: Image Fields
Plugin URI: https://www.tipsandtricks-hq.com/?p=8580
Description: Easily add image citation fields of your WordPress images.
Version: 1.0
Author: Keith Lock
Author URI: https://www.tipsandtricks-hq.com
Translated: Luis Méndez ALejo @gnumax - 2016
License: GPL
*/

$tthqkl_text_domain = "tthqkl_text_domain";
$tthqkl_att_options = array(
    'tthqkl_image_name' => array(
        'label'         => __( 'Nombre imagen', $tthqkl_text_domain ),
        'input'         => 'text',
        'helps'         => __( 'Escribe le nombre de la imagen', $tthqkl_text_domain ),
        'application'   => 'image',
        'exclusions'    => array( 'audio', 'video', 'document' )
    ),
    'tthqkl_image_source_url' => array(
        'label'               => __( 'URL origen imagen', $tthqkl_text_domain ),
        'input'               => 'text',
        'helps'               => __( 'Introduce la URL donde se puede encontrar la imagen, si está disponible', $tthqkl_text_domain ),
        'application'         => 'image',
        'exclusions'          => array( 'audio', 'video', 'document' )
    ),
    'tthqkl_image_author_name' => array(
        'label'                => __( 'Avatar del autor de la imagen', $tthqkl_text_domain ),
        'input'                => 'text',
        'helps'                => __( 'Introduce el nombre del autor de imagen, si está disponible', $tthqkl_text_domain ),
        'application'          => 'image',
        'exclusions'           => array( 'audio', 'video', 'document' )
    ),
    'tthqkl_image_author_url' => array(
        'label'               => __( 'URL del autor de la imagen', $tthqkl_text_domain ),
        'input'               => 'text',
        'helps'               => __( 'Introduce la URL del autor, si está disponible', $tthqkl_text_domain ),
        'application'         => 'image',
        'exclusions'          => array( 'audio', 'video', 'document' )
    ),
    'tthqkl_image_license'   => array(
        'label'       => __( 'Licencia', $tthqkl_text_domain ),
        'input'       => 'select',
        'options'     => array(
            'none' => __( 'Ninguna', $tthqkl_text_domain ),
            'https://creativecommons.org/publicdomain/zero/1.0/|CC0' => __( 'CC0', $tthqkl_text_domain ),
            'http://creativecommons.org/licenses/by/4.0/|CC BY 4.0' => __( 'CC BY 4.0', $tthqkl_text_domain )
        ),
        'application' => 'image',
        'exclusions'  => array( 'audio', 'video', 'document' )
    ),
    'tthqkl_image_miscellaneous' => array(
        'label'                  => __( 'Varios', $tthqkl_text_domain ),
        'input'                  => 'text',
        'helps'                  => __( 'Puedes llenar opcionalmente en esta casilla si deseas añadir información adicional, o describir cualquier modificación a la imagen, o proporcionar una licencia "Compartir igual", si es aplicable', $tthqkl_text_domain ),
        'application'            => 'image',
        'exclusions'             => array( 'audio', 'video', 'document' )
    )
);

class tthqkl_img_citations_meta_box {

    private $media_fields = array();
    
    function __construct( $fields ) {
        $this->media_fields = $fields;
        add_filter( 'attachment_fields_to_edit', array( $this, 'applyFilter' ), 11, 2 );
        add_filter( 'attachment_fields_to_save', array( $this, 'saveFields' ), 11, 2 );
    }
 
    public function applyFilter( $form_fields, $post = null ) {
        if ( ! empty( $this->media_fields ) ) {
            foreach ( $this->media_fields as $field => $values ) {
                if ( preg_match( "/" . $values['application'] . "/", $post->post_mime_type) && ! in_array( $post->post_mime_type, $values['exclusions'] ) ) {
                    $meta = get_post_meta( $post->ID, '_' . $field, true );
                    switch ( $values['input'] ) {
                        default:
                        case 'text':
                            $values['input'] = 'text';
                            break;
                        case 'select':
                            $values['input'] = 'html';
                            $html = '<select name="attachments[' . $post->ID . '][' . $field . ']">';
                            if ( isset( $values['options'] ) ) {
                                foreach ( $values['options'] as $k => $v ) {
                                    if ( $meta == $k ) {
                                        $selected = ' selected="selected"';
                                    } else {
                                        $selected = '';
                                    }
                                    $html .= '<option' . $selected . ' value="' . $k . '">' . $v . '</option>';
                                }
                            }
                            $html .= '</select>';
                            $values['html'] = $html;
                            break;
                    }
                    $values['value'] = $meta;
                   $form_fields[$field] = $values;
                }
            }
        }
        return $form_fields;
    }
 
    function saveFields( $post, $attachment ) {
        if ( ! empty( $this->media_fields ) ) {
            foreach ( $this->media_fields as $field => $values ) {
                if ( isset( $attachment[$field] ) ) {
                    update_post_meta( $post['ID'], '_' . $field, $attachment[$field] );
                }
            }
        }
        return $post;
    }
} 
$tthqkl_img_citations_meta_box = new tthqkl_img_citations_meta_box( $tthqkl_att_options );

function tthqkl_draw_citation_line($attachment_id) {
    $attributions .= '&bull; ';
    if (get_post_meta($attachment_id, '_tthqkl_image_source_url', true)) {
        $attributions .= '<a href="' . get_post_meta($attachment_id, '_tthqkl_image_source_url', true) . '" target="_blank">' . get_post_meta($attachment_id, '_tthqkl_image_name', true) . '</a>';
    } else {
        $attributions .= get_post_meta($attachment_id, '_tthqkl_image_name', true);
    }
    if (get_post_meta($attachment_id, '_tthqkl_image_author_name', true)) {
        $attributions .= ' del autor ';
        if (get_post_meta($attachment_id, '_tthqkl_image_author_url', true)) {
            $attributions .= '<a href="' . get_post_meta($attachment_id, '_tthqkl_image_author_url', true) . '" target="_blank">'  . get_post_meta($attachment_id, '_tthqkl_image_author_name', true) . '</a>';
        } else {
            $attributions .= get_post_meta($attachment_id, '_tthqkl_image_author_name', true);
        }
    }
    if (get_post_meta($attachment_id, '_tthqkl_image_license', true) != 'none') {
        $attributions .= ' está licenciada como ';
        $pipe_pos = strpos(get_post_meta($attachment_id, '_tthqkl_image_license', true), '|');
        if ($pipe_pos === false) {
            $license_name = get_post_meta($attachment_id, '_tthqkl_image_license', true);
            $license_url = '';
        } else {
            $license_params = explode('|', get_post_meta($attachment_id, '_tthqkl_image_license', true));
            $license_name = $license_params[1];
            $license_url = $license_params[0];
        }
        if ($license_url != '') {
            $attributions .= '<a href="' . $license_url . '" target="_blank">'  . $license_name . '</a>';
        } else {
            $attributions .= $license_name;
        }
    }
    if (get_post_meta($attachment_id, '_tthqkl_image_miscellaneous', true)) {
        $attributions .= ', ' . get_post_meta($attachment_id, '_tthqkl_image_miscellaneous', true);
    }
    return $attributions;
}

function tthqkl_content_append_image_citation($content) {
    if (is_singular() && is_main_query()) {
        $attachments = get_children( array('post_parent' => get_the_ID(), 'post_type' => 'attachment', 'post_mime_type' =>'image') );
        foreach ( $attachments as $attachment_id => $attachment ) {
            if (get_post_meta($attachment_id, '_tthqkl_image_name', true)) {
                $attributions .= tthqkl_draw_citation_line($attachment_id);
            }
            if ($attributions != '') {
                $attributions .= '<br />';
            }
        }
        if ($attributions != '') {
            $new_content = '<p><strong>Créditos de la imagen:</strong><br />' . $attributions . '</p>';
            if (get_post_thumbnail_id()) {
                $new_content .= '<p><strong>Créditos de la imagen destacada:</strong><br />' . tthqkl_draw_citation_line(get_post_thumbnail_id()) . '</p>';
            }
        }
        $content .= $new_content;
    }	
    return $content;
}
add_filter('the_content', 'tthqkl_content_append_image_citation');